<?php

namespace PortalPeople\virtualstock\exceptions;

class AuthenticationException extends ApiException
{
    public function __construct(
        string $message = 'VirtualStock API authentication failed (403)',
        string $responseBody = '',
        ?\Throwable $previous = null
    ) {
        parent::__construct($message, 403, $responseBody, $previous);
    }
}
