<?php

namespace PortalPeople\virtualstock\models\carts;

use Yii;

class Virtualstock extends \common\models\DynamicModel
{
    public static function segment_title(): string
    {
        return 'VirtualStock Attributes';
    }

    public static function localattributes(): array
    {
        return [
            'order_no' => [
                'rules' => [
                    ['string'],
                ],
                'label' => Yii::t('app', 'Order Number'),
                'input' => 'default',
            ],
            'status' => [
                'rules' => [
                    ['string'],
                ],
                'label' => Yii::t('app', 'Status'),
                'input' => 'default',
            ],
            'last_sync' => [
                'rules' => [
                    ['string'],
                ],
                'label' => Yii::t('app', 'Last Sync'),
                'input' => 'default',
            ],
            'updated_at_source' => [
                'rules' => [
                    ['string'],
                ],
                'label' => Yii::t('app', 'Source Updated At'),
                'input' => 'default',
            ],
            'shipments_json' => [
                'rules' => [
                    ['string'],
                ],
                'label' => Yii::t('app', 'Shipments JSON'),
                'input' => 'default',
            ],
            'last_error' => [
                'rules' => [
                    ['string'],
                ],
                'label' => Yii::t('app', 'Last Error'),
                'input' => 'default',
            ],
        ];
    }

    public function dataLoad($modelData): void
    {
    }
}
